#
# spec file for package urbanlightscape
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           urbanlightscape
Version:        1.4.0
Release:        bp156.3.6
Summary:        Improve Lighting, Correct Exposure, Add Synthetic Light to Photos
License:        GPL-2.0+
Group:          Productivity/Graphics/Bitmap Editors
Url:            http://www.indii.org/software/urbanlightscape
Source0:        http://www.indii.org/files/%{name}/releases/%{name}-%{version}.tar.gz
Source1:        http://www.indii.org/images/%{name}_128.png
BuildRequires:  ImageMagick
BuildRequires:  bc
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-devel >= 3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#Appliaction heavily depends on SSE, which is Intel specific feature
ExclusiveArch:  %{ix86} x86_64

%description
Urban Lightscape is a photo filter for exposure correction,
localized brightness adjustments, dodging and burning, and the
introduction of synthetic lighting to a photo. A simple
"double-click-and-drag" paradigm is used to place control points on
a photo, and clever edge detection localises and interpolates
lightness adjustments around and between these points. Results are
rapid, with additional controls for more subtle refinements.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags} -msse2"
%configure --disable-assert
make %{?_smp_mflags}

%install
%make_install
# Create desktop file.
cat > %{name}.desktop << EOF
[Desktop Entry]
Name=Urban Lightscape
GenericName=Correct Exposure, Lighting, Brightness
GenericName[ru]=Коррекция экспозиции, яркости, света
Type=Application
Exec=urbanlightscape %f
Icon=urbanlightscape
Categories=Graphics;Photography;
Comment=Improve lighting, Correct Exposure, Add Synthetic Light to Photos
Comment[ru]=Коррекция экспозиции, яркости, света
StartupNotify=true
Terminal=false
MimeType=image/gif;image/jpeg;image/png;image/tiff;image/x-bmp;image/x-portable-pixmap;image/x-pcx;image/x-targa;image/x-xpm;
EOF
install -Dm 0644 %{name}.desktop \
    %{buildroot}%{_datadir}/applications/%{name}.desktop

# Install icons of various sizes.
install -Dm 0644 %{SOURCE1} \
    %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
for size in 96x96 64x64 48x48 32x32 22x22 16x16 ; do
    install -dm 0755 \
        %{buildroot}%{_datadir}/icons/hicolor/${size}/apps
    convert -strip -resize ${size} %{SOURCE1} \
        %{buildroot}%{_datadir}/icons/hicolor/${size}/apps/%{name}.png
done
%suse_update_desktop_file %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root,-)
%doc COPYING README
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/%{name}.*

%changelog
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Jun  2 2016 lazy.kent@opensuse.org
- Fix "find requires" (remove %%wx_requires).
* Sun Dec 13 2015 lazy.kent@opensuse.org
- Update to 1.4.0.
  * Maintenance release.
- BuildRequires: wxWidgets-3_0-devel >= 3, bc.
* Sun Aug 17 2014 lazy.kent@opensuse.org
- Add -msse2 to CXXFLAGS to fix build for i586.
* Mon Jul  7 2014 lazy.kent@opensuse.org
- Update to 1.3.3.
  * Maintenance release.
- Changes in 1.3.2.
  * Fixed crash bug for particular image sizes.
- Changes in 1.3.1.
  * Retina display support.
* Sat Oct 19 2013 lazy.kent@opensuse.org
- Correct the source URL because of OBS download service issue.
* Sun Oct  6 2013 lazy.kent@opensuse.org
- Update to 1.3.0.
  * Added 16 and 32 bits per channel support to plugin.
  * Window size and position now preserved between launches.
* Sat Apr  6 2013 dvaleev@suse.com
- Appliaction heavily depends on SSE, which is Intel specific
  feature. Set ExclusiveArch to x86
* Thu Dec 27 2012 lazy.kent@opensuse.org
- Update to 1.2.3.
  * Fixed compile error on Linux under wxWidgets 2.8.
- Changes in 1.2.2.
  * Fixed crash bug on some images.
- Changes in 1.2.1.
  * Adjustment at newly added control points now inferred from
    existing points.
* Sat Aug  4 2012 lazy.kent@opensuse.org
- Update to 1.2.0.
  * Added Tolerance slider.
  * Fixed occasional crash bugs.
* Sat Apr  7 2012 lazy.kent@opensuse.org
- Update to 1.1.0.
  * Performance improvements when interacting with control points.
* Sun Mar 18 2012 lazy.kent@opensuse.org
- Update to 1.0.4.
  * Fixed zoom-fit function.
  * Fixed GCC 4.6 compile errors.
* Tue Mar 13 2012 lazy.kent@opensuse.org
- Initial package created - 1.0.3.
